Type: Package
Package: quollr
Title: Visualising How Nonlinear Dimension Reduction Warps Your Data
Version: 1.0.6
Authors@R: c(
    person("Jayani P.", "Gamage", , "jayanilakshika76@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-6265-6481")),
    person("Dianne", "Cook", , "dicook@monash.edu", role = "aut",
           comment = c(ORCID = "0000-0002-3813-7155")),
    person("Paul", "Harrison", , "paul.harrison@monash.edu", role = "aut",
           comment = c(ORCID = "0000-0002-3980-268X")),
    person("Michael", "Lydeamore", , "michael.lydeamore@monash.edu", role = "aut",
           comment = c(ORCID = "0000-0001-6515-827X")),
    person("Thiyanga S.", "Talagala", , "ttalagala@sjp.ac.lk", role = "aut",
           comment = c(ORCID = "0000-0002-0656-9789"))
  )
Description: To construct a model in 2-D space from 2-D nonlinear
    dimension reduction data and then lift it to the high-dimensional
    space. Additionally, provides tools to visualise the model overlay the
    data in 2-D and high-dimensional space. Furthermore, provides
    summaries and diagnostics to evaluate the nonlinear dimension
    reduction layout.
License: MIT + file LICENSE
URL: https://jayanilakshika.github.io/quollr/
BugReports: https://github.com/jayanilakshika/quollr/issues
Depends: R (>= 4.1.0)
Imports: cli, crosstalk, dplyr, ggplot2, grid, htmltools, interp (>=
        1.1-6), langevitour, patchwork, plotly, proxy, purrr, Rcpp,
        rsample, stats, tibble, tidyr, tidyselect
Suggests: detourr, knitr, rmarkdown, testthat (>= 3.0.0), vdiffr
LinkingTo: Rcpp, RcppArmadillo
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-GB
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: yes
Packaged: 2025-12-18 08:16:20 UTC; jpiy0001
Author: Jayani P. Gamage [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-6265-6481>),
  Dianne Cook [aut] (ORCID: <https://orcid.org/0000-0002-3813-7155>),
  Paul Harrison [aut] (ORCID: <https://orcid.org/0000-0002-3980-268X>),
  Michael Lydeamore [aut] (ORCID:
    <https://orcid.org/0000-0001-6515-827X>),
  Thiyanga S. Talagala [aut] (ORCID:
    <https://orcid.org/0000-0002-0656-9789>)
Maintainer: Jayani P. Gamage <jayanilakshika76@gmail.com>
Repository: CRAN
Date/Publication: 2025-12-18 10:10:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-30 15:13:55 UTC; unix
Archs: quollr.so.dSYM
