# Generated by roxygen2: do not edit by hand

S3method(augment,highd_vis_model)
S3method(glance,highd_vis_model)
export(assign_data)
export(augment)
export(avg_highd_data)
export(calc_2d_dist)
export(calc_bins_y)
export(comb_all_data_model)
export(comb_all_data_model_error)
export(comb_data_model)
export(compute_mean_density_hex)
export(compute_std_counts)
export(find_low_dens_hex)
export(find_non_empty_bins)
export(fit_highd_model)
export(gen_axes)
export(gen_centroids)
export(gen_design)
export(gen_diffbin1_errors)
export(gen_edges)
export(gen_hex_coord)
export(gen_scaled_data)
export(geom_hexgrid)
export(geom_trimesh)
export(get_projection)
export(glance)
export(group_hex_pts)
export(hex_binning)
export(merge_hexbin_centroids)
export(merge_hexbin_mean)
export(plot_hbe_layouts)
export(plot_proj)
export(predict_emb)
export(quad)
export(show_error_link_plots)
export(show_langevitour)
export(show_link_plots)
export(stat_hexgrid)
export(stat_trimesh)
export(tri_bin_centroids)
export(update_trimesh_index)
importFrom(Rcpp,evalCpp)
importFrom(dplyr,across)
importFrom(dplyr,arrange)
importFrom(dplyr,between)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,count)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,first)
importFrom(dplyr,group_by)
importFrom(dplyr,inner_join)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,nth)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,select)
importFrom(dplyr,summarise)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(ggplot2,Geom)
importFrom(ggplot2,GeomPoint)
importFrom(ggplot2,GeomSegment)
importFrom(ggplot2,Stat)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_path)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,layer)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_linedraw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(grid,grobTree)
importFrom(interp,tri.mesh)
importFrom(interp,triangles)
importFrom(langevitour,langevitour)
importFrom(plotly,config)
importFrom(plotly,highlight)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(plotly,style)
importFrom(proxy,dist)
importFrom(rsample,starts_with)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(tibble,add_row)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
importFrom(tidyselect,all_of)
importFrom(tidyselect,everything)
importFrom(tidyselect,starts_with)
useDynLib(quollr, .registration = TRUE)
